DomainResponse class
Constructors
-
DomainResponse.fromJson(Map<
String, dynamic> json)
Properties
-
data
↔ Map<
String, dynamic> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- message ↔ DomainMessage
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ DomainStatus
-
getter/setter pair
Methods
-
isFailure(
) → bool -
isLoading(
) → bool -
isSuccess(
) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
exception(
Object e) → DomainResponse -
failure(
DomainMessage message) → DomainResponse -
loading(
) → DomainResponse -
success(
Map< String, dynamic> data) → DomainResponse